@@ -299,9 +299,10 @@ sub _html_head
 sub _navigation
 {
     output( "\n" );
-    output( "<a name=\"$_[0]\"></a>\n" ) if length( $_[0] );
+    output( "<p><a name=\"$_[0]\"></a></p>\n" ) if length( $_[0] );
     output( "<hr>\n" );
     output( "\n" );
+    output( "<p>\n" );
     output( "[ " );
     _output_ref( $locale{ 'previous' }, '',
 		 $previous{ $chapter_id }, $previous{ $chapter_id } );
@@ -330,6 +331,7 @@ sub _navigation
     _output_ref( $locale{ 'next' }, '',
 		 $next{ $chapter_id }, $next{ $chapter_id } );
     output( " ]\n" );
+    output( "</p>\n" );
 }
 
 sub _html_tail
@@ -339,6 +341,7 @@ sub _html_tail
     output( "\n" );
     output( "<p>\n" );
     output( "$title\n" );
+    output( "</p>\n" );
     output( "\n" );
     output( "<address>\n" );
     if ( length( $version ) )
@@ -363,7 +366,6 @@ sub _html_tail
 	output( "<br>\n" );
     }
     output( "</address>\n" );
-    output( "\n" );
     output( "<hr>\n" );
     output( "\n" );
     output( "</body>\n" );
@@ -449,6 +451,7 @@ sub _output_copyright
     output( "\n" );
     output( "<p>\n" );
     output( join( "<br>\n", @copyrightsummary ), "\n" );
+    output( "</p>\n" );
     output( $_[0] );
     $copyright = pop_output;
 }
@@ -473,11 +476,11 @@ sub _output_toc
 	my $toc_entry_level = $toc_entry_level{ $toc_entry_id };
 	if ( $toc_level > $toc_entry_level )
 	{
-	    output( "</ul>\n" x ( $toc_level - $ toc_entry_level) );
+	    output( "</ul></li>\n" x ( $toc_level - $ toc_entry_level) );
 	}
 	elsif ( $toc_level < $toc_entry_level )
 	{
-	    output( "<ul>\n" x ( $toc_entry_level - $toc_level ) );
+	    output( "<li><ul>\n" x ( $toc_entry_level - $toc_level ) );
 	}
 	output( "<li>" );
 	_output_ref( "$toc_entry_id $toc_entry_name{ $toc_entry_id }", '',
@@ -486,7 +489,8 @@ sub _output_toc
 	output( "</li>\n" );
 	$toc_level = $toc_entry_level;
     }
-    output( "</ul>\n" x ( $toc_level + 2 ) );
+    output( "</ul></li>\n" x ( $toc_level + 1 ) );
+    output( "</ul>\n" );
     $toc = pop_output;
 }
 sub _output_tocentry
@@ -535,6 +539,21 @@ sub _output_appendix
     $chapter_type{ $chapter_id } = $chapter_type;
     push( @chapter_id, $chapter_id );
 
+}
+sub _output_sect
+{
+}
+sub _output_sect1
+{
+}
+sub _output_sect2
+{
+}
+sub _output_sect3
+{
+}
+sub _output_sect4
+{
 }
 sub _output_heading
 {
@@ -565,8 +584,8 @@ sub _output_heading
 	output( "\n" );
 	output( "<hr>\n" );
 	output( "\n" );
-	output( "<a name=\"$_[3]\"></a>\n" );
 	output( "<h" . ( $_[1] + 2 ) . ">" );
+	output( "<a name=\"$_[3]\"></a>" );
 	output( "$_[2] " ) if length( $_[2] );
 	output( $_[0] );
         output( "</h" . ( $_[1] + 2 ) . ">\n" );
@@ -579,18 +598,18 @@ sub _output_heading
 ## ----------------------------------------------------------------------
 sub _output_p
 {
+    if ( $need_hr )
+    {
+	output( "\n" );
+	output( "<hr>\n" );
+	$need_hr = 0;
+    }
     if ( length( $_[0] ) )
     {
-	if ( $need_hr )
-	{
-	    output( "\n" );
-	    output( "<hr>\n" );
-	    #output( "\n" );
-	    $need_hr = 0;
-	}
 	output( "\n" ) if ! $DebianDoc_SGML::Format::Driver::is_compact;
 	output( "<p>\n" );
 	output( $text->format( "$_[0]\n" ) );
+	output( "</p>\n" );
     }
     else
     {
@@ -708,15 +727,32 @@ sub _output_enumlist
     {
 	$type = 'i';
     }
-    if ( $DebianDoc_SGML::Format::Driver::is_compact )
+    if ( $DebianDoc_SGML::Format::Driver::opt_x )
     {
-	output( "<ol " );
-	output( "type=\"$type\" " );
-	output( "start=\"" . $DebianDoc_SGML::Format::Driver::item_counter . "\" " );
-	output( ">\n" );
+	output( "<ol>\n" );
+    }
+    else
+    {
+        if ( $DebianDoc_SGML::Format::Driver::is_compact )
+	{
+	    output( "<!-- ol " );
+	    output( "type=\"$type\" " );
+	    output( "start=\"" . $DebianDoc_SGML::Format::Driver::item_counter . "\" " );
+	    output( " -->\n" );
+	}
     }
     output( $_[0] );
-    output( "</ol>\n" ) if $DebianDoc_SGML::Format::Driver::is_compact;
+    if ( $DebianDoc_SGML::Format::Driver::opt_x )
+    {
+    output( "</ol>\n" );
+    }
+    else
+    {
+        if ( $DebianDoc_SGML::Format::Driver::is_compact )
+	{
+	    output( "</ol>\n" );
+	}
+    }
 }
 sub _output_taglist
 {
@@ -736,7 +772,7 @@ sub _output_taglist_tag
 sub _output_list_item
 {
     $_[0] =~ s/^\n//;
-    $_[0] =~ s/^<p>\n//;
+#    $_[0] =~ s/^<p>\n//;
     output( "<ul>\n" ) if ! $DebianDoc_SGML::Format::Driver::is_compact;
     output( "<li>\n" );
     output( $_[0] );
@@ -763,23 +799,32 @@ sub _output_enumlist_item
 	$type = 'i';
     }
     $_[0] =~ s/^\n//;
-    $_[0] =~ s/^<p>\n//;
-    if ( ! $DebianDoc_SGML::Format::Driver::is_compact )
+#    $_[0] =~ s/^<p>\n//;
+    if ( ! $DebianDoc_SGML::Format::Driver::opt_x )
     {
-	output( "<ol " );
-	output( "type=\"$type\" " );
-	output( "start=\"".$DebianDoc_SGML::Format::Driver::item_counter."\" " );
-	output( ">\n" );
+	if ( ! $DebianDoc_SGML::Format::Driver::is_compact )
+	{
+	    output( "<ol " );
+	    output( "type=\"$type\" " );
+	    output( "start=\"".$DebianDoc_SGML::Format::Driver::item_counter."\" " );
+	    output( ">\n" );
+	}
     }
     output( "<li>\n" );
     output( $_[0] );
     output( "</li>\n" );
-    output( "</ol>\n" ) if ! $DebianDoc_SGML::Format::Driver::is_compact;
+    if ( ! $DebianDoc_SGML::Format::Driver::opt_x )
+    {
+        if ( ! $DebianDoc_SGML::Format::Driver::is_compact )
+	{
+	    output( "</ol>\n" );
+	}
+    }
 }
 sub _output_taglist_item
 {
     $_[0] =~ s/^\n//;
-    $_[0] =~ s/^<p>\n//;
+#    $_[0] =~ s/^<p>\n//;
     output( "<dl>\n" ) if ! $DebianDoc_SGML::Format::Driver::is_compact;
     foreach ( @{$_[1]} )
     {
