@@ -74,8 +74,9 @@ sub _output_start_book
 	if length( $locale{ 'inputenc' } );
     output( "\\usepackage[T1]{fontenc}\n" );
     output( "\n" );
+    output( "\\usepackage{ifpdf}\n" );
     output( "\\usepackage{pifont}\n" );
-    output( "\\usepackage{textcomp}\n" );
+    output( "\\usepackage[force]{textcomp}\n" );
     output( "\\usepackage{wasysym}\n" );
     output( "\n" );
     output( "\\usepackage{babel}\n\n" )
@@ -122,13 +123,13 @@ sub _output_start_book
     output( "\\usepackage{varioref}\n" );
     output( "\\vrefwarning\n" );
     output( "\n" );
-    output( "\\ifx\\pdfoutput\\undefined\n" );
-    output( "\\usepackage[hypertex,colorlinks=true]{hyperref}\n" );
-    output( "\\else\n" );
-    output( "\\usepackage[pdftex,colorlinks=true" );
+    output( "\\ifpdf\n" );
+    output( "\\usepackage[colorlinks=true" );
     output( ",$locale{ 'pdfhyperref' }" )
     	if (length( $locale{ 'pdfhyperref' } ));
     output( "]{hyperref}\n" );
+    output( "\\else\n" );
+    output( "\\usepackage[hypertex]{hyperref}\n" );
     output( "\\fi\n" );
     output( "\n" );
     output( "\\parindent=0pt\n" );
@@ -301,6 +302,21 @@ sub _output_appendix
 {
     output( $_[0] );
 }
+sub _output_sect
+{
+}
+sub _output_sect1
+{
+}
+sub _output_sect2
+{
+}
+sub _output_sect3
+{
+}
+sub _output_sect4
+{
+}
 sub _output_heading
 {
     if ( $_[1] == -2 && ! $set_appendix )
